@@ -2,7 +2,7 @@ class GridSearchResult:
     """
     Result of a grid search iteration
     """
-    def __init__(self, dataset, clf, accuracy, resources=None, inference_time=None):
+    def __init__(self, dataset, clf, accuracy, resources=None, inference_time=None, passes=False, fail_reason=None):
         """
         
         """
@@ -11,3 +11,5 @@ class GridSearchResult:
         self.accuracy = accuracy
         self.resources = resources
         self.inference_time = inference_time
+        self.passes = passes
+        self.fail_reason = fail_reason
